#
# In place to read the shared library
#

#.First.lib <- function(libpath, libname)
#  {
#    library.dynam(libname)
#  }

#.onLoad <- function(libname, pkgname)
#  {
#    print(paste("loading lib '",libname,"' part of package '",pkgname,"'",sep=''))
#    library.dynam(chname=pkgname)
#  }
